Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/qmc5883l_simpletest.py
    :caption: examples/qmc5883l_simpletest.py
    :lines: 5-

Advanced Settings
------------------

Example showing how to set up the sensor with advanced settings

.. literalinclude:: ../examples/qmc5883l_advanced_settings.py
    :caption: examples/qmc5883l_advanced_settings.py
    :lines: 6-

Oversample Settings
-------------------

Example showing the oversample setting

.. literalinclude:: ../examples/qmc5883l_oversample.py
    :caption: examples/qmc5883l_oversample.py
    :lines: 5-

Data Rate Settings
-------------------

Example showing the data rate setting

.. literalinclude:: ../examples/qmc5883l_data_rate.py
    :caption: examples/qmc5883l_data_rate.py
    :lines: 5-

Field Range Settings
--------------------

Example showing the field range setting

.. literalinclude:: ../examples/qmc5883l_field_range.py
    :caption: examples/qmc5883l_field_range.py
    :lines: 5-

Magnetic Compss
--------------------

Example showing the field range setting

.. literalinclude:: ../examples/qmc5883l_magnetic_compass.py
    :caption: examples/qmc5883l_magnetic_compass.py
    :lines: 9-
